# pynter
Tools for atomistic calculations. Uses the [`pymatgen`](https://pymatgen.org) package. The main features are designed to systematically run, analyse and plot DFT point defect calculations with VASP. 

It can be installed with the Python Package Index (PyPI) by running:
```sh
pip install pynter-defects
```

To configure settings for High-Performance Computer job submissions and for VASP calculations, run:
```sh
pynter configure
```

Check-out the tutorials in the [`pynter-tutorials`](https://github.com/lorenzo-villa-hub/pynter-tutorials) repository. For an introduction consult this notebook:
[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/lorenzo-villa-hub/pynter-tutorials/blob/master/notebooks/intro.ipynb)
